// Cyphesis Online RPG Server and AI Engine
// Copyright (C) 2009 Alistair Riddoch
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
// 
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
// GNU General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software Foundation,
// Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA


#ifndef COMMON_CUSTOM_H
#define COMMON_CUSTOM_H

namespace Atlas { namespace Objects { namespace Operation {

extern int ACTUATE_NO;
extern int ADD_NO;
extern int ATTACK_NO;
extern int BURN_NO;
extern int CONNECT_NO;
extern int DROP_NO;
extern int EAT_NO;
extern int GOAL_INFO_NO;
extern int MONITOR_NO;
extern int NOURISH_NO;
extern int PICKUP_NO;
extern int SETUP_NO;
extern int THOUGHT_NO;
extern int TICK_NO;
extern int UNSEEN_NO;
extern int UPDATE_NO;
extern int TELEPORT_NO;
extern int COMMUNE_NO;
extern int THINK_NO;
extern int RELAY_NO;

} } }

#endif // COMMON_CUSTOM_H
